# ----------------------------------------------------------------------------------------------
# --------------- Measures for security assurance Project defined vs. Personally ---------------
# ----------------------------------------------------------------------------------------------
fossanalyze.measure_proj_vs_pers <- function (saveFile=FALSE, projectType="web", projectPhase="design", file="measure") {

# Plot constants 
if(projectType == "web") {
    projectTypeText <- "WEB INFORMATION systems"
    projectTypeInd <- 1
    fileName <- paste(file, "_web", sep = "")
} else if(projectType == "sys") {
    projectTypeText <- "SYSTEMS or INFRASTRUCTURES"
    projectTypeInd <- 2
    fileName <- paste(file, "_sys", sep = "")
} else {
    projectTypeText <- "OTHER projects"
    projectTypeInd <- 3
    fileName <- paste(file, "_other", sep = "")
}

if(projectPhase == "design") {
    projectPhaseText <- "DESIGN"
    measures <- designMeasures
    measuresLab <- designMeasuresLab
    nmAll <- foss$CB_WHICH_MEASURES_DESIGN_ALL[foss$RB_TYPE_OF_PROJECT %in% grep(projTypes[projectTypeInd], foss$RB_TYPE_OF_PROJECT, value=TRUE)]
    nmPers <- foss$CB_WHICH_MEASURES_DESIGN_PERS[foss$RB_TYPE_OF_PROJECT %in% grep(projTypes[projectTypeInd], foss$RB_TYPE_OF_PROJECT, value=TRUE)]
    fileName <- paste(fileName, "_design", sep = "")
} else if(projectPhase == "impl") {
    projectPhaseText <- "IMPLEMENTATION"
    measures <- implMeasures
    measuresLab <- implMeasuresLab
    nmAll <- foss$CB_WHICH_MEASURES_IMPL_ALL[foss$RB_TYPE_OF_PROJECT %in% grep(projTypes[projectTypeInd], foss$RB_TYPE_OF_PROJECT, value=TRUE)]
    nmPers <- foss$CB_WHICH_MEASURES_IMPL_PERS[foss$RB_TYPE_OF_PROJECT %in% grep(projTypes[projectTypeInd], foss$RB_TYPE_OF_PROJECT, value=TRUE)]
    fileName <- paste(fileName, "_impl", sep = "")
} else if(projectPhase == "test") {
    projectPhaseText <- "TESTING"
    measures <- testMeasures
    measuresLab <- testMeasureslab
    nmAll <- foss$CB_WHICH_MEASURES_TEST_ALL[foss$RB_TYPE_OF_PROJECT %in% grep(projTypes[projectTypeInd], foss$RB_TYPE_OF_PROJECT, value=TRUE)]
    nmPers <- foss$CB_WHICH_MEASURES_TEST_PERS[foss$RB_TYPE_OF_PROJECT %in% grep(projTypes[projectTypeInd], foss$RB_TYPE_OF_PROJECT, value=TRUE)]
    fileName <- paste(fileName, "_test", sep = "")
} else {
    projectPhaseText <- "MAINTENANCE"
    measures <- mainMeasures
    measuresLab <- mainMeasuresLab
    nmAll <- foss$CB_WHICH_MEASURES_MAINTNC_ALL[foss$RB_TYPE_OF_PROJECT %in% grep(projTypes[projectTypeInd], foss$RB_TYPE_OF_PROJECT, value=TRUE)]
    nmPers <- foss$CB_WHICH_MEASURES_MAINTNC_PERS[foss$RB_TYPE_OF_PROJECT %in% grep(projTypes[projectTypeInd], foss$RB_TYPE_OF_PROJECT, value=TRUE)]
    fileName <- paste(fileName, "_main", sep = "")
}

mainText <- paste("Measures for security assurance used during \nthe ", projectPhaseText, " of ", projectTypeText, ".", sep = "")
ylabText <- percenText;
xlabText <- "Conducted measures";
legendLab <- c("Conducted by other project members", "Conducted personally")

#Normirung Maximal Wert
normMax <- 100

nmAllLen <- length(nmAll)
nmPersLen <- length(nmPers)

if(length(measures)>=1)
measures_1 <- c(length(nmAll[nmAll %in% grep(measures[1], nmAll, value=TRUE)])/nmAllLen*normMax,
                length(nmPers[nmPers %in% grep(measures[1], nmPers, value=TRUE)])/nmPersLen*normMax)
if(length(measures)>=2)
measures_2 <- c(length(nmAll[nmAll %in% grep(measures[2], nmAll, value=TRUE)])/nmAllLen*normMax,
                length(nmPers[nmPers %in% grep(measures[2], nmPers, value=TRUE)])/nmPersLen*normMax)
if(length(measures)>=3)
measures_3 <- c(length(nmAll[nmAll %in% grep(measures[3], nmAll, value=TRUE)])/nmAllLen*normMax,
                length(nmPers[nmPers %in% grep(measures[3], nmPers, value=TRUE)])/nmPersLen*normMax)
if(length(measures)>=4)
measures_4 <- c(length(nmAll[nmAll %in% grep(measures[4], nmAll, value=TRUE)])/nmAllLen*normMax,
                length(nmPers[nmPers %in% grep(measures[4], nmPers, value=TRUE)])/nmPersLen*normMax)
if(length(measures)>=5)
measures_5 <- c(length(nmAll[nmAll %in% grep(measures[5], nmAll, value=TRUE)])/nmAllLen*normMax,
                length(nmPers[nmPers %in% grep(measures[5], nmPers, value=TRUE)])/nmPersLen*normMax)
if(length(measures)>=6)
measures_6 <- c(length(nmAll[nmAll %in% grep(measures[6], nmAll, value=TRUE)])/nmAllLen*normMax,
                length(nmPers[nmPers %in% grep(measures[6], nmPers, value=TRUE)])/nmPersLen*normMax)
if(length(measures)>=7)
measures_7 <- c(length(nmAll[nmAll %in% grep(measures[6], nmAll, value=TRUE)])/nmAllLen*normMax,
                length(nmPers[nmPers %in% grep(measures[6], nmPers, value=TRUE)])/nmPersLen*normMax)

# construct values vector
if(length(measures) == 5) 
    measuresVector <- c(measures_1, measures_2, measures_3, measures_4, measures_5)
if(length(measures) == 6) 
    measuresVector <- c(measures_1, measures_2, measures_3, measures_4, measures_5, measures_6)
if(length(measures) == 7) 
    measuresVector <- c(measures_1, measures_2, measures_3, measures_4, measures_5, measures_6, measures_7)

# add total number of members
lenVector <- c(nmAllLen, nmPersLen)
measuresLab <- paste(measuresLab, "\n(", lenVector, " part.)", sep="")

# construct matrix to plot
plotMatrix <- matrix(measuresVector,
                nrow = 2, ncol = length(measures), byrow = FALSE,
                dimnames = list(legendLab, measuresLab))

# if "saveFile", than save as png image:
if (saveFile) png(paste(fileName, "png", sep="."), width=700, height=700)

#Plot parameters
par(mai = c(1.2, 1.2, 0.7, 0)) # margin size (bottom, left, top, right) specified in inches. 
par(mgp = c(4.5, 3, 0)) # margin line for (the axis title, axis labels, axis line)
par(cex.lab = 1.2) # label size 

#Draw Plot
barplot(plotMatrix, beside = TRUE, cex.names = 1.0, axis.lty = 0,
        col = c("lightskyblue", "palegreen"),
        main=mainText, ylab=ylabText, xlab=xlabText,
        legend = rownames(plotMatrix),
        ylim = c(0, normMax))
grid(0, 10)

# if "saveFile", stop output-redirection to file
if (saveFile) dev.off()

}

#Function call with different parameters
isSaveFile <- TRUE
fossanalyze.measure_proj_vs_pers(isSaveFile, "web", "design")
fossanalyze.measure_proj_vs_pers(isSaveFile, "web", "impl")
fossanalyze.measure_proj_vs_pers(isSaveFile, "web", "test")
fossanalyze.measure_proj_vs_pers(isSaveFile, "web", "main")

fossanalyze.measure_proj_vs_pers(isSaveFile, "sys", "design")
fossanalyze.measure_proj_vs_pers(isSaveFile, "sys", "impl")
fossanalyze.measure_proj_vs_pers(isSaveFile, "sys", "test")
fossanalyze.measure_proj_vs_pers(isSaveFile, "sys", "main")

fossanalyze.measure_proj_vs_pers(isSaveFile, "other", "design")
fossanalyze.measure_proj_vs_pers(isSaveFile, "other", "impl")
fossanalyze.measure_proj_vs_pers(isSaveFile, "other", "test")
fossanalyze.measure_proj_vs_pers(isSaveFile, "other", "main")
